==> lavaps_1.9.orig.tar.gz: lavaps-1.9/main.cc <==

/*
 * main.cc
 * Copyright (C) 1999 by John Heidemann
 * $Id: main.cc,v 1.19 1999/11/18 05:50:07 johnh Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include <unistd.h>
#include <stdlib.h>
#include <iostream.h>

#include <string>


#include "main.hh"

#ifdef USE_TCL_BLOB
#include "tcl_blob.hh"
#endif /* USE_TCL_BLOB */

#ifdef USE_TEXT_BLOB
#include "text_blob.hh"
#endif /* USE_TEXT_BLOB */


int filter_good_uid = 0,
	filter_good_pid = 0;
bool allow_autosize = true;
bool lava_debug = false;
proc_filter_style_enum filter_style;
change_tracking<vm_style_enum> report_vm(ERROR_MEM);  // resources set it
string default_resources = "";

void
usage()
{
	cout << "usage: lavaps\n" << "\tUse the about menu for info.\n";
	exit(1);
}

void
die(char *s)
{
	cerr << s;
	exit(1);
}

int
lava_random(int limit)
{
	static int inited = 0;
	if (!inited) {
		inited = 1;
		srandom(1); // time();
	};
	if (limit == 0)
		return 0;
	else return random() % limit;
}

void
parse_args(int argc, char **argv)
{
#if 0
	int c;

        while ((c = getopt(argc, argv, "?")) != EOF)
                switch (c) {
		default:
			usage();
			break;
                };
#endif /* 0 */
	int i = 0;
	for (i = 1; i < argc; i++) {
		char *opt = argv[i];
		if (opt[0] == '-' && opt[1] == '-')
			opt++;   // handle -- same as - options
		char *optarg = NULL;
		if (i+1 < argc)
			optarg = argv[i+1];
		if (strcmp(argv[i], "-display") == 0 && optarg) {
			setenv("DISPLAY", optarg, 1);
			i++;
		} else if (strcmp(argv[i], "-geometry") == 0 && optarg) {
			default_resources += "lavaps.geometry: ";
			default_resources += optarg;
			i++;
		} else {
			usage();
			exit(1);
		};
	};
}

int
main(int argc, char **argv)
{
	parse_args(argc, argv);

	filter_good_uid = getuid();
#ifdef USE_TCL_BLOB
	tcl_blob::init();
	tcl_blob::mainloop();
#endif /* USE_TCL_BLOB */
#ifdef USE_TEXT_BLOB
	text_blob::mainloop();
#endif /* USE_TEXT_BLOB */
}

==> lavaps-1.15.tar.gz: lavaps-1.15/main.cc <==

/*
 * main.cc
 * Copyright (C) 1999-2000 by John Heidemann
 * $Id: main.cc,v 1.20 2000/02/12 05:11:21 johnh Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 */


#include <unistd.h>
#include <stdlib.h>
#include <iostream.h>

#include <string>


#include "main.hh"

#ifdef USE_TCL_BLOB
#include "tcl_blob.hh"
#endif /* USE_TCL_BLOB */

#ifdef USE_TEXT_BLOB
#include "text_blob.hh"
#endif /* USE_TEXT_BLOB */


int filter_good_uid = 0,
	filter_good_pid = 0;
bool allow_autosize = true;
bool lava_debug = false;
proc_filter_style_enum filter_style;
change_tracking<vm_style_enum> report_vm(ERROR_MEM);  // resources set it
string default_resources = "";

void
usage()
{
	cout << "usage: lavaps\n" << "\tUse the about menu for info.\n";
	exit(1);
}

void
die(char *s)
{
	cerr << s;
	exit(1);
}

int
lava_random(int limit)
{
	static int inited = 0;
	if (!inited) {
		inited = 1;
		srandom(1); // time();
	};
	if (limit == 0)
		return 0;
	else return random() % limit;
}

void
parse_args(int argc, char **argv)
{
#if 0
	int c;

        while ((c = getopt(argc, argv, "?")) != EOF)
                switch (c) {
		default:
			usage();
			break;
                };
#endif /* 0 */
	int i = 0;
	for (i = 1; i < argc; i++) {
		char *opt = argv[i];
		if (opt[0] == '-' && opt[1] == '-')
			opt++;   // handle -- same as - options
		char *optarg = NULL;
		if (i+1 < argc)
			optarg = argv[i+1];
		if (strcmp(argv[i], "-display") == 0 && optarg) {
			(void) setenv("DISPLAY", optarg, 1);
			i++;
		} else if (strcmp(argv[i], "-geometry") == 0 && optarg) {
			default_resources += "lavaps.geometry: ";
			default_resources += optarg;
			i++;
		} else {
			usage();
			exit(1);
		};
	};
}

int
main(int argc, char **argv)
{
	parse_args(argc, argv);

	filter_good_uid = getuid();
#ifdef USE_TCL_BLOB
	tcl_blob::init();
	tcl_blob::mainloop();
#endif /* USE_TCL_BLOB */
#ifdef USE_TEXT_BLOB
	text_blob::mainloop();
#endif /* USE_TEXT_BLOB */
}
